@@ -61,7 +61,6 @@ option add *dialog*txt*font -*-courier-bold-r-normal--14-*
 
 toplevel .xcircuit -width 1000 -height 800 -background red
 wm title .xcircuit XCircuit
-# tk_setPalette red
 
 # This gets rid of the original "wish", in favor of our own window
 
@@ -124,15 +123,15 @@ pack .xcircuit.menubar.filebutton .xcircuit.menubar.editbutton \
 
 # The bottom message bar
 
-tklabel .xcircuit.menubar.message -text "Welcome to Xcircuit v3.1" \
+label .xcircuit.menubar.message -text "Welcome to Xcircuit v3.1" \
 	-background beige -justify left -anchor w
 pack .xcircuit.menubar.message -side top -fill x -padx 2 -ipady 3 -pady 2
 
 button .xcircuit.infobar.symb -text "Symbol" -bg gray30 -fg white
 button .xcircuit.infobar.schem -text "Schematic" -bg red -fg white
-tklabel .xcircuit.infobar.message1 -text "Editing: Page 1" \
+label .xcircuit.infobar.message1 -text "Editing: Page 1" \
 	-background beige
-tklabel .xcircuit.infobar.message2 -text "Grid 1/6 in : Snap 1/12 in" \
+label .xcircuit.infobar.message2 -text "Grid 1/6 in : Snap 1/12 in" \
 	-background beige -justify left -anchor w
 pack .xcircuit.infobar.symb .xcircuit.infobar.schem \
 	.xcircuit.infobar.message1 -side left -padx 2 -ipadx 6 -fill y
@@ -341,6 +340,18 @@ proc xcircuit::coordstyle { { mode get } } {
    }
 }
 
+proc xcircuit::raiseconsole {} {
+   xcircuit::consoleup
+   .xcircuit.menubar.filebutton.filemenu entryconfigure \
+	 4 -label "No Console" -command {xcircuit::lowerconsole}
+}
+
+proc xcircuit::lowerconsole {} {
+   xcircuit::consoledown
+   .xcircuit.menubar.filebutton.filemenu entryconfigure \
+	 4 -label "Tcl Console" -command {xcircuit::raiseconsole}
+}
+
 #----------------------------------------------------------------------
 # Command tags---these let the command-line entry functions update the
 # Tk windows, so that the Tk window structure doesn't need to be hard-
@@ -393,8 +404,8 @@ grid rowconfigure .filelist.listwin 0 -weight 1 -minsize 100
 frame .filelist.textent.title -bg beige
 pack .filelist.textent.title -side top -fill x
 
-tklabel .filelist.textent.title.field -text "Select file to load:" -bg beige
-tklabel .filelist.textent.title.chklabel -text "Filter" -bg beige
+label .filelist.textent.title.field -text "Select file to load:" -bg beige
+label .filelist.textent.title.chklabel -text "Filter" -bg beige
 checkbutton .filelist.textent.title.filter -bg beige -variable filter \
    -command {event generate .filelist.listwin.win <ButtonPress> -button 3 ; \
 	event generate .filelist.listwin.win <ButtonRelease> -button 3}
@@ -436,20 +447,20 @@ pack .output.title -side top -padx 20 -pady 7 -fill x
 pack .output.textent -side top -padx 20 -pady 7 -fill x
 pack .output.bbar -side top -padx 20 -pady 7 -fill x
 
-tklabel .output.title.field -text "PostScript output properties (Page 1):" -bg tan
+label .output.title.field -text "PostScript output properties (Page 1):" -bg tan
 checkbutton .output.title.multi -text "1 page" -bg beige -variable multiple \
 	-command {.output.textent.txt1 delete 0 end; .output.textent.but1 configure \
 	-text Apply; xcircuit::page filename {}; focus .output.textent.txt1}
 
 pack .output.title.field -side left
 
-tklabel .output.textent.lab1 -text "Filename:" -bg beige
-tklabel .output.textent.lab2 -text "Page label:" -bg beige
-tklabel .output.textent.lab3 -text "Scale:" -bg beige
-tklabel .output.textent.lab4 -text "Width:" -bg beige
-tklabel .output.textent.lab5 -text "Height:" -bg beige
-tklabel .output.textent.lab6 -text "Orientation:" -bg beige
-tklabel .output.textent.lab7 -text "Mode:" -bg beige
+label .output.textent.lab1 -text "Filename:" -bg beige
+label .output.textent.lab2 -text "Page label:" -bg beige
+label .output.textent.lab3 -text "Scale:" -bg beige
+label .output.textent.lab4 -text "Width:" -bg beige
+label .output.textent.lab5 -text "Height:" -bg beige
+label .output.textent.lab6 -text "Orientation:" -bg beige
+label .output.textent.lab7 -text "Mode:" -bg beige
 
 entry .output.textent.txt1 -bg white -relief sunken -width 20
 entry .output.textent.txt2 -bg white -relief sunken -width 20
@@ -588,7 +599,7 @@ frame .help.listwin
 pack .help.title -side top -fill x
 pack .help.listwin -side top -fill both -expand true
 
-tklabel .help.title.field -text "XCircuit Help" -bg beige
+label .help.title.field -text "XCircuit Help" -bg beige
 button .help.title.dbut -text "Dismiss" -bg beige -command {wm withdraw .help}
 pack .help.title.field -side left -padx 10
 pack .help.title.dbut -side right -ipadx 10
@@ -633,7 +644,7 @@ entry .dialog.textent.txt -bg white -relief sunken -width 50
 pack .dialog.textent.title -side top -fill x
 pack .dialog.textent.txt -side bottom -fill x -expand true
 
-tklabel .dialog.textent.title.field -text "Select file to load:" -bg beige
+label .dialog.textent.title.field -text "Select file to load:" -bg beige
 pack .dialog.textent.title.field -side left
 
 button .dialog.bbar.okay -text Okay -bg beige
@@ -657,7 +668,7 @@ frame .query.bbar	-bg beige
 pack .query.title -side top -padx 20 -pady 7 -fill x
 pack .query.bbar -side top -padx 20 -pady 7 -fill x
 
-tklabel .query.title.field -text "Select:" -bg beige
+label .query.title.field -text "Select:" -bg beige
 pack .query.title.field -side left
 
 button .query.bbar.okay -text Okay -bg beige
@@ -833,9 +844,15 @@ proc xcircuit::promptloadlibrary {} {
 
 proc xcircuit::promptsavelib { libno } {
    .dialog.bbar.okay configure -command \
-	"xcircuit::library $libno save [.dialog.textent.txt get];\
-	 wm withdraw .dialog"
+	[subst {xcircuit::library $libno save \[.dialog.textent.txt get\];\
+	 wm withdraw .dialog}]
    .dialog.textent.title.field configure -text "Enter name for library:"
+   .dialog.textent.txt delete 0 end
+   set lname [xcircuit::library $libno]
+   if {[string first Library: $lname] == 0} \
+      {set lname [string range $lname 8 end]}
+   set lname [string trimleft $lname]
+   .dialog.textent.txt insert 0 [string map {" " _} $lname]
    wm deiconify .dialog
    focus .dialog.textent.txt
 }
@@ -1182,7 +1199,7 @@ $m add command -label "Read XCircuit File" -command {xcircuit::promptloadfile}
 $m add command -label "Import XCircuit PS" -command {xcircuit::promptimportfile}
 $m add command -label "Import background PS" -command {xcircuit::promptimportbackground}
 $m add command -label "Execute Script" -command {xcircuit::promptexecscript}
-$m add command -label "Tcl Console" -command {xcircuit::consoleup}
+$m add command -label "Tcl Console" -command {xcircuit::raiseconsole}
 $m add command -label "Write XCircuit PS" -command {xcircuit::promptsavepage}
 $m add separator
 $m add command -label "Add To Library" -command {xcircuit::promptaddlibrary}
