@@ -213,7 +213,7 @@ void pagecatbutton(XButtonEvent *event)
 	       /* using changepage() allows use of new page for schematic */
 	       changepage(bpage);
 	       /* associate the new schematic */
-	       schemassoc(topobject, xobjs.stack->thisinst->thisobject);
+	       schemassoc(topobject, areastruct.stack->thisinst->thisobject);
 	       /* pop back to calling (symbol) page */
 	       catreturn();
 	       eventmode = PRESS_MODE;
@@ -1305,9 +1305,9 @@ void catbutton(u_int mode, XButtonEvent *event)
 	       if (eventmode == ASSOC_MODE) {
 
 	          /* revert to old page */
-	          areastruct.topinstance = (xobjs.stack == NULL) ?
+	          areastruct.topinstance = (areastruct.stack == NULL) ?
 			   xobjs.pagelist[areastruct.page]->pageinst
-			   : xobjs.stack->thisinst;
+			   : areastruct.stack->thisinst;
 		  /* associate the new object */
 		  schemassoc(topobject, (*libobj)->thisobject); 
    	          setpage(TRUE);
@@ -1320,9 +1320,9 @@ void catbutton(u_int mode, XButtonEvent *event)
 
 	          /* revert to old page */
 
-	          areastruct.topinstance = (xobjs.stack == NULL) ?
+	          areastruct.topinstance = (areastruct.stack == NULL) ?
 			   xobjs.pagelist[areastruct.page]->pageinst
-			   : xobjs.stack->thisinst;
+			   : areastruct.stack->thisinst;
 
 	          /* retrieve drawing window state and set position of object to
 	             be correct in reference to that window */
@@ -1485,7 +1485,7 @@ void startcatalog(xcWidget w, pointertype libmod, caddr_t nulldata)
 		|| (areastruct.topinstance == xobjs.libtop[LIBLIB])
 		|| (areastruct.topinstance == xobjs.libtop[PAGELIB]))
 		&& libmod >= PAGELIB)) {
-      push_stack(&xobjs.stack, areastruct.topinstance);
+      push_stack(&areastruct.stack, areastruct.topinstance);
    }
 
    /* set library as new object */
